==> commons-imaging-1.0a1-sources.jar: org/apache/commons/imaging/formats/tiff/taginfos/TagInfoLong.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.commons.imaging.formats.tiff.taginfos;

import java.nio.ByteOrder;

import org.apache.commons.imaging.common.ByteConversions;
import org.apache.commons.imaging.formats.tiff.constants.TiffDirectoryType;
import org.apache.commons.imaging.formats.tiff.fieldtypes.FieldType;


public class TagInfoLong extends TagInfo {
    public TagInfoLong(final String name, final int tag, final TiffDirectoryType directoryType) {
        super(name, tag, FieldType.LONG, 1, directoryType);
    }
    
    public TagInfoLong(final String name, final int tag, final TiffDirectoryType directoryType, final boolean isOffset) {
        super(name, tag, FieldType.LONG, 1, directoryType, isOffset);
    }
    
    public int getValue(final ByteOrder byteOrder, final byte[] bytes) {
        return ByteConversions.toInt(bytes, byteOrder);
    }
    
    public byte[] encodeValue(final ByteOrder byteOrder, final int value) {
        return ByteConversions.toBytes(value, byteOrder);
    }
}

==> commons-imaging-1.0-20230603.215407-229-sources.jar: org/apache/commons/imaging/formats/tiff/taginfos/TagInfoLong.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.commons.imaging.formats.tiff.taginfos;

import java.nio.ByteOrder;
import java.util.List;

import org.apache.commons.imaging.common.ByteConversions;
import org.apache.commons.imaging.formats.tiff.constants.TiffDirectoryType;
import org.apache.commons.imaging.formats.tiff.fieldtypes.FieldType;


public class TagInfoLong extends TagInfo {
    public TagInfoLong(final String name, final int tag, final List<FieldType> dataTypes, final int length,
        final TiffDirectoryType exifDirectory, final boolean isOffset) {
        super(name, tag, dataTypes, length, exifDirectory, isOffset);
    }

    public TagInfoLong(final String name, final int tag, final TiffDirectoryType directoryType) {
        super(name, tag, FieldType.LONG, 1, directoryType);
    }

    public TagInfoLong(final String name, final int tag, final TiffDirectoryType directoryType, final boolean isOffset) {
        super(name, tag, FieldType.LONG, 1, directoryType, isOffset);
    }

    public byte[] encodeValue(final ByteOrder byteOrder, final int value) {
        return ByteConversions.toBytes(value, byteOrder);
    }

    public int getValue(final ByteOrder byteOrder, final byte[] bytes) {
        return ByteConversions.toInt(bytes, byteOrder);
    }
}
